%define module  mpi4py
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so

Summary:       MPI for Python
Name:          python-%{module}
Version:       1.3.1
Release:       %mkrel 4
Source0:       https://bitbucket.org/mpi4py/mpi4py/downloads/%{module}-%{version}.tar.gz
License:       Public Domain
Group:         Development/Python
Url:           https://bitbucket.org/mpi4py
Requires:      openmpi
BuildRequires: pkgconfig(python)
BuildRequires: python-cython
BuildRequires: openmpi
BuildRequires: pkgconfig(ompi)
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(python3)
BuildRequires: python3-cython

%description
MPI for Python provides bindings of the Message Passing Interface
(MPI) standard for the Python programming language, allowing any
Python program to exploit multiple processors.

This package is constructed on top of the MPI-1/2 specifications and
provides an object oriented interface which closely follows MPI-2 C++
bindings. It supports point-to-point (sends, receives) and collective
(broadcasts, scatters, gathers) communications of any picklable Python
object, as well as optimized communications of Python object exposing
the single-segment buffer interface (NumPy arrays, builtin
bytes/string/array objects).

%package devel
Summary:    mpi4py headers
Group:      Development/Python
Requires:   %{name} = %{version}-%{release}

%description devel 
This package contains header files needed to develop modules in C or
Fortran that can interact with mpi4py.

%package doc
Summary:    Documentation for mpi4py
Group:      Development/Python
BuildArch:  noarch

%description doc
This package contains documentation for MPI for Python.

%package -n python3-%{module}
Summary:    Python 3 bindings of the Message Passing Interface (MPI)
Group:      Development/Python

%description -n python3-%{module}
MPI for Python provides bindings of the Message Passing Interface
(MPI) standard for the Python programming language, allowing any
Python 3 program to exploit multiple processors.

This package is constructed on top of the MPI-1/2 specifications and
provides an object oriented interface which closely follows MPI-2 C++
bindings. It supports point-to-point (sends, receives) and collective
(broadcasts, scatters, gathers) communications of any picklable Python
object, as well as optimized communications of Python object exposing
the single-segment buffer interface (NumPy arrays, builtin
bytes/string/array objects).

%package -n python3-%{module}-devel
Summary:    mpi4py headers
Group:      Development/Python
Requires:   python3-%{module} = %{version}-%{release}

%description -n python3-%{module}-devel 
This package contains header files needed to develop modules in C or
Fortran that can interact with mpi4py.

%prep
%setup -q -n %{module}-%{version}
# delete docs/source
# this is just needed to generate docs/*
rm -r docs/source

# work around "wrong-file-end-of-line-encoding"
for file in $(find | grep runtests.bat); do
    sed -i 's/\r//' $file
done

cp -a . %{py3dir} 

%build
export CFLAGS="-Wno-error=format-security" 
CFLAGS="%{optflags}" %{__python} setup.py build

pushd %{py3dir}
CFLAGS="%{optflags}" %{__python3} setup.py build
popd

%install
%{__python} setup.py install --root=%{buildroot} --skip-build
rm -f %{buildroot}%{python_sitearch}/mpi4py/mpi.cfg

pushd %{py3dir} 
%{__python3} setup.py install --root=%{buildroot} --skip-build
rm -f %{buildroot}%{python3_sitearch}/mpi4py/mpi.cfg
popd


%files
%{python_sitearch}/%{module}*
%exclude %{python_sitearch}/%{module}/include/

%files devel
%{python_sitearch}/%{module}/include/

%files doc
%doc test/ demo/ *.txt docs/usrman docs/apiref

%files -n python3-%{module}
%{python3_sitearch}/%{module}*
%exclude %{python3_sitearch}/%{module}/include/

%files -n python3-%{module}-devel
%{python3_sitearch}/%{module}/include/


%changelog
* Sun Dec 01 2013 philippem <philippem> 1.3.1-4.mga4
+ Revision: 554555
- add Python 3, split doc in sub package

* Tue Oct 22 2013 umeabot <umeabot> 1.3.1-3.mga4
+ Revision: 543732
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.3.1-2.mga4
+ Revision: 498939
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Aug 27 2013 philippem <philippem> 1.3.1-1.mga4
+ Revision: 472330
- update to 1.3.1

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jun 14 2012 eatdirt <eatdirt> 1.3-2.mga3
+ Revision: 260541
- Rebuild for new openmpi-1.6

* Thu Jun 14 2012 fwang <fwang> 1.3-1.mga3
+ Revision: 260447
- update file list
- update file list

  + lebedov <lebedov>
    - Update to 1.3.

* Fri Jan 13 2012 eatdirt <eatdirt> 1.2.2-2.mga2
+ Revision: 195649
- Rebuild against openmpi-1.4.4

* Tue Sep 20 2011 lebedov <lebedov> 1.2.2-1.mga2
+ Revision: 146091
- imported package python-mpi4py

